==> vue-skeleton-2.22.1.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import MobileFirstTemplate from "./mobile-first.js";
import "@opentinyvue/vue-theme/skeleton/index.css";
var template = function template2(mode) {
  var _process$env;
  var tinyMode = typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  if ("pc" === (tinyMode || mode)) {
    return PcTemplate;
  }
  if ("mobile-first" === (tinyMode || mode)) {
    return MobileFirstTemplate;
  }
  return PcTemplate;
};
var $constants = {};
var skeletonProps = _extends({}, $props, {
  _constants: {
    type: Object,
    default: function _default() {
      return $constants;
    }
  },
  modelValue: String,
  loading: {
    type: Boolean,
    default: true
  },
  rows: {
    type: Number,
    default: 3
  },
  avatar: {
    type: Boolean,
    default: false
  },
  rowsWidth: {
    type: Array,
    default: function _default2() {
      return [];
    }
  },
  animated: {
    type: Boolean,
    default: true
  }
});
var Skeleton = defineComponent({
  name: $prefix + "Skeleton",
  props: skeletonProps,
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "2.undefined";
Skeleton.model = {
  prop: "modelValue",
  event: "update:modelValue"
};
Skeleton.install = function(Vue) {
  Vue.component(Skeleton.name, Skeleton);
};
Skeleton.version = version;
export {
  Skeleton as default
};

==> vue-skeleton-2.23.0.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import MobileFirstTemplate from "./mobile-first.js";
import "@opentinyvue/vue-theme/skeleton/index.css";
var template = function template2(mode) {
  var _process$env;
  var tinyMode = typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  if ("pc" === (tinyMode || mode)) {
    return PcTemplate;
  }
  if ("mobile-first" === (tinyMode || mode)) {
    return MobileFirstTemplate;
  }
  return PcTemplate;
};
var $constants = {};
var skeletonProps = _extends({}, $props, {
  _constants: {
    type: Object,
    default: function _default() {
      return $constants;
    }
  },
  modelValue: String,
  loading: {
    type: Boolean,
    default: true
  },
  rows: {
    type: Number,
    default: 3
  },
  avatar: {
    type: Boolean,
    default: false
  },
  rowsWidth: {
    type: Array,
    default: function _default2() {
      return [];
    }
  },
  animated: {
    type: Boolean,
    default: true
  }
});
var Skeleton = defineComponent({
  name: $prefix + "Skeleton",
  props: skeletonProps,
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "2.23.0";
Skeleton.model = {
  prop: "modelValue",
  event: "update:modelValue"
};
Skeleton.install = function(Vue) {
  Vue.component(Skeleton.name, Skeleton);
};
Skeleton.version = version;
export {
  Skeleton as default
};
